@@ -1,5 +1,5 @@
 /* nbdkit
- * Copyright (C) 2019-2020 Red Hat Inc.
+ * Copyright Red Hat
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -58,7 +58,7 @@ struct extent {
   uint64_t offset, length;
   uint32_t type;
 };
-DEFINE_VECTOR_TYPE(extent_list, struct extent);
+DEFINE_VECTOR_TYPE (extent_list, struct extent);
 static extent_list extents;
 
 static void
@@ -226,15 +226,16 @@ parse_extentlist (void)
    */
   for (i = 0; i < extents.len-1; ++i) {
     end = extents.ptr[i].offset + extents.ptr[i].length;
-    if (end < extents.ptr[i+1].offset)
-      if (extent_list_insert (&extents,
-                              (struct extent){.offset = end,
-                                              .length = extents.ptr[i+1].offset - end,
-                                              .type = HOLE},
-                              i+1) == -1) {
+    if (end < extents.ptr[i+1].offset) {
+      struct extent extent = { .offset = end,
+                               .length = extents.ptr[i+1].offset - end,
+                               .type = HOLE };
+
+      if (extent_list_insert (&extents, extent, i+1) == -1) {
         nbdkit_error ("realloc: %m");
         exit (EXIT_FAILURE);
       }
+    }
   }
 
   /* If there's a gap at the end, insert a hole|zero extent. */
@@ -328,4 +329,4 @@ static struct nbdkit_filter filter = {
   .extents           = extentlist_extents,
 };
 
-NBDKIT_REGISTER_FILTER(filter)
+NBDKIT_REGISTER_FILTER (filter)
