@@ -108,6 +108,9 @@ NBDKIT_EXTERN_DECL (int64_t, nbdkit_parse_size, (const char *str));
 NBDKIT_EXTERN_DECL (int, nbdkit_parse_probability,
                     (const char *what, const char *str, double *r));
 NBDKIT_EXTERN_DECL (int, nbdkit_parse_bool, (const char *str));
+NBDKIT_EXTERN_DECL (int, nbdkit_parse_delay,
+                    (const char *what, const char *str,
+                     unsigned *sec, unsigned *nsec));
 NBDKIT_EXTERN_DECL (int, nbdkit_parse_int,
                     (const char *what, const char *str, int *r));
 NBDKIT_EXTERN_DECL (int, nbdkit_parse_unsigned,
@@ -139,6 +142,8 @@ NBDKIT_EXTERN_DECL (int64_t, nbdkit_peer_pid, (void));
 NBDKIT_EXTERN_DECL (int64_t, nbdkit_peer_uid, (void));
 NBDKIT_EXTERN_DECL (int64_t, nbdkit_peer_gid, (void));
 NBDKIT_EXTERN_DECL (char *, nbdkit_peer_security_context, (void));
+NBDKIT_EXTERN_DECL (char *, nbdkit_peer_tls_dn, (void));
+NBDKIT_EXTERN_DECL (char *, nbdkit_peer_tls_issuer_dn, (void));
 NBDKIT_EXTERN_DECL (void, nbdkit_shutdown, (void));
 NBDKIT_EXTERN_DECL (void, nbdkit_disconnect, (int force));
 
