@@ -60,15 +60,18 @@
 #endif
 
 #if defined (__linux__) && HAVE_LINUX_FS_H
-#include <linux/fs.h>       /* For BLKZEROOUT */
+#include <linux/fs.h>       /* For BLK* constants. */
 #endif
 
 #define NBDKIT_API_VERSION 2
 #include <nbdkit-plugin.h>
 
 #include "cleanup.h"
-#include "isaligned.h"
 #include "fdatasync.h"
+#include "isaligned.h"
+#include "ispowerof2.h"
+#include "minmax.h"
+#include "utils.h"
 
 static enum {
   mode_none,
@@ -182,8 +185,7 @@ file_unload (void)
 static int
 file_config (const char *key, const char *value)
 {
-  /* See FILENAMES AND PATHS in nbdkit-plugin(3).
-   * Our use of nbdkit_realpath requires the destination to exist at
+  /* Our use of nbdkit_realpath requires the destination to exist at
    * startup; use nbdkit_absolute_path instead if we wanted to defer
    * existence checks to the last possible moment.
    */
@@ -372,6 +374,12 @@ file_config_complete (void)
 static void
 file_dump_plugin (void)
 {
+#if defined(BLKIOMIN) && defined(BLKIOOPT)
+  printf ("file_block_size=yes\n");
+#endif
+#ifdef BLKROTATIONAL
+  printf ("file_blkrotational=yes\n");
+#endif
 #ifdef BLKSSZGET
   printf ("file_blksszget=yes\n");
 #endif
@@ -468,8 +476,11 @@ file_list_exports (int readonly, int default_only,
 /* The per-connection handle. */
 struct handle {
   int fd;
+  struct stat statbuf;
   bool is_block_device;
   int sector_size;
+  unsigned short rotational;
+  uint32_t minimum, preferred, maximum;
   bool can_write;
   bool can_punch_hole;
   bool can_zero_range;
@@ -521,7 +532,6 @@ static void *
 file_open (int readonly)
 {
   struct handle *h;
-  struct stat statbuf;
   const char *file;
 
   h = malloc (sizeof *h);
@@ -631,7 +641,7 @@ file_open (int readonly)
 
   assert (h->fd >= 0);
 
-  if (fstat (h->fd, &statbuf) == -1) {
+  if (fstat (h->fd, &h->statbuf) == -1) {
     nbdkit_error ("fstat: %s: %m", file);
     close (h->fd);
     free (h);
@@ -649,9 +659,9 @@ file_open (int readonly)
 #endif
   }
 
-  if (S_ISBLK (statbuf.st_mode))
+  if (S_ISBLK (h->statbuf.st_mode))
     h->is_block_device = true;
-  else if (S_ISREG (statbuf.st_mode))
+  else if (S_ISREG (h->statbuf.st_mode))
     h->is_block_device = false;
   else {
     nbdkit_error ("file is not regular or block device: %s", file);
@@ -659,15 +669,49 @@ file_open (int readonly)
     free (h);
     return NULL;
   }
-  h->sector_size = 4096;  /* Start with safe guess */
 
+  h->sector_size = 4096; /* Start with safe guess */
 #ifdef BLKSSZGET
   if (h->is_block_device) {
-    if (ioctl (h->fd, BLKSSZGET, &h->sector_size))
+    if (ioctl (h->fd, BLKSSZGET, &h->sector_size) == -1)
       nbdkit_debug ("cannot get sector size: %s: %m", file);
   }
 #endif
 
+  h->rotational = 0; /* Default before nbdkit 1.40 */
+#ifdef BLKROTATIONAL
+  if (h->is_block_device) {
+    if (ioctl (h->fd, BLKROTATIONAL, &h->rotational) == -1)
+      nbdkit_debug ("cannot get rotational property: %s: %m", file);
+  }
+#endif
+
+  h->minimum = h->preferred = h->maximum = 0;
+#if defined(BLKIOMIN) && defined(BLKIOOPT)
+  if (h->is_block_device) {
+    unsigned int minimum_io_size = 0, optimal_io_size = 0;
+
+    if (ioctl (h->fd, BLKIOMIN, &minimum_io_size) == -1)
+      nbdkit_debug ("cannot get BLKIOMIN: %s: %m", file);
+
+    if (ioctl (h->fd, BLKIOOPT, &optimal_io_size) == -1)
+      nbdkit_debug ("cannot get BLKIOOPT: %s: %m", file);
+    else if (optimal_io_size == 0)
+      /* All devices in the Linux kernel except for MD report optimal
+       * as 0.  In that case guess a good value.
+       */
+      optimal_io_size = MAX (minimum_io_size, 4096);
+
+    /* Check the values are sane before using them. */
+    if (minimum_io_size >= 512 && is_power_of_2 (minimum_io_size) &&
+        optimal_io_size >= minimum_io_size && is_power_of_2 (optimal_io_size)) {
+      h->minimum = minimum_io_size;
+      h->preferred = optimal_io_size;
+      h->maximum = 0xffffffff;
+    }
+  }
+#endif
+
 #ifdef FALLOC_FL_PUNCH_HOLE
   h->can_punch_hole = true;
 #else
@@ -701,43 +745,42 @@ file_close (void *handle)
 
 #define THREAD_MODEL NBDKIT_THREAD_MODEL_PARALLEL
 
-/* For block devices, stat->st_size is not the true size.  The caller
- * grabs the lock.
- */
-static int64_t
-block_device_size (int fd)
-{
-  off_t size;
-
-  size = lseek (fd, 0, SEEK_END);
-  if (size == -1) {
-    nbdkit_error ("lseek (to find device size): %m");
-    return -1;
-  }
-
-  return size;
-}
-
 /* Get the file size. */
 static int64_t
 file_get_size (void *handle)
+{
+  ACQUIRE_LOCK_FOR_CURRENT_SCOPE (&lseek_lock); /* device_size may seek */
+  struct handle *h = handle;
+  int64_t r;
+
+  r = device_size (h->fd, &h->statbuf);
+  if (r == -1) {
+    nbdkit_error ("device_size: %m");
+    return -1;
+  }
+  return r;
+}
+
+/* Check if file is rotational. */
+static int
+file_is_rotational (void *handle)
 {
   struct handle *h = handle;
 
-  if (h->is_block_device) {
-    ACQUIRE_LOCK_FOR_CURRENT_SCOPE (&lseek_lock);
-    return block_device_size (h->fd);
-  } else {
-    /* Regular file. */
-    struct stat statbuf;
+  return h->rotational;
+}
 
-    if (fstat (h->fd, &statbuf) == -1) {
-      nbdkit_error ("fstat: %m");
-      return -1;
-    }
+/* Return minimum, preferred and maximum block size. */
+static int
+file_block_size (void *handle, uint32_t *minimum,
+                 uint32_t *preferred, uint32_t *maximum)
+{
+  struct handle *h = handle;
 
-    return statbuf.st_size;
-  }
+  *minimum = h->minimum;
+  *preferred = h->preferred;
+  *maximum = h->maximum;
+  return 0;
 }
 
 /* Check if file is read-only. */
@@ -1167,6 +1210,8 @@ static struct nbdkit_plugin plugin = {
   .open              = file_open,
   .close             = file_close,
   .get_size          = file_get_size,
+  .is_rotational     = file_is_rotational,
+  .block_size        = file_block_size,
   .can_write         = file_can_write,
   .can_multi_conn    = file_can_multi_conn,
   .can_trim          = file_can_trim,
