@@ -28,12 +28,14 @@
 (* Disk image with default size. *)
 let disk = ref (Bytes.make (1024*1024) '\000')
 
+(* This is called when the plugin is loaded. *)
 let load () =
   (* Debugging output is only printed when the server is in
    * verbose mode (nbdkit -v option).
    *)
   NBDKit.debug "example OCaml plugin loaded"
 
+(* This is called when the plugin is unloaded. *)
 let unload () =
   NBDKit.debug "example OCaml plugin unloaded"
 
@@ -45,6 +47,9 @@ let dump_plugin () =
   Printf.printf "ocamlexample_data=42\n";
   flush stdout
 
+(* This is called for every [key=value] parameter passed to the plugin
+ * on the command line.
+ *)
 let config key value =
   match key with
   | "size" ->
@@ -53,6 +58,10 @@ let config key value =
   | _ ->
      failwith (Printf.sprintf "unknown parameter: %s" key)
 
+(* A debug flag (see example-debug-flag.c) *)
+external ocamlexample_debug_foo : unit -> int =
+  "get_ocamlexample_debug_foo" [@@noalloc]
+
 (* Any type (even unit) can be used as a per-connection handle.
  * This is just an example.  The same value that you return from
  * your [open_connection] function is passed back as the first
@@ -63,27 +72,38 @@ type handle = {
 }
 
 let id = ref 0
+
+(* An NBD client has opened a connection. *)
 let open_connection readonly =
   let export_name = NBDKit.export_name () in
   NBDKit.debug "example OCaml plugin handle opened readonly=%b export=%S"
     readonly export_name;
+  NBDKit.debug "debug flag: -D ocamlexample.foo=%d" (ocamlexample_debug_foo ());
   incr id;
   { h_id = !id }
 
+(* Return the size of the disk. *)
 let get_size h =
   NBDKit.debug "example OCaml plugin get_size id=%d" h.h_id;
   Int64.of_int (Bytes.length !disk)
 
-let pread h count offset _ =
-  let buf = Bytes.create count in
-  Bytes.blit !disk (Int64.to_int offset) buf 0 count;
-  Bytes.unsafe_to_string buf
-
-let pwrite h buf offset _ =
-  let len = String.length buf in
+(* Read part of the disk.  This should modify the buf parameter
+ * directly as shown below.
+ *)
+let pread h buf offset _ =
+  let len = NBDKit.buf_len buf in
   let offset = Int64.to_int offset in
-  String.blit buf 0 !disk offset len
+  NBDKit.blit_bytes_to_buf !disk offset buf 0 len
 
+(* Write part of the disk. *)
+let pwrite h buf offset _ =
+  let len = NBDKit.buf_len buf in
+  let offset = Int64.to_int offset in
+  NBDKit.blit_buf_to_bytes buf 0 !disk offset len
+
+(* Set the plugin thread model.  [SERIALIZE_ALL_REQUESTS] is a
+ * safe default.
+ *)
 let thread_model () =
   NBDKit.THREAD_MODEL_SERIALIZE_ALL_REQUESTS
 
@@ -95,10 +115,11 @@ let version =
    *)
   NBDKit.version ()
 
+(* The plugin must be registered once by calling [register_plugin].
+ * name, open_connection, get_size and pread are required,
+ * everything else is optional.
+ *)
 let () =
-  (* name, open_connection, get_size and pread are required,
-   * everything else is optional.
-   *)
   NBDKit.register_plugin
     ~name: "ocamlexample"
     ~version
