@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 # nbdkit
-# Copyright (C) 2018 Red Hat Inc.
+# Copyright Red Hat
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are
@@ -35,21 +35,17 @@ set -e
 set -x
 
 requires_filter cache
-requires nbdsh --version
+requires_nbdsh_uri
 
-sock=`mktemp -u`
-files="cache-on-read.img $sock cache-on-read.pid"
+sock=$(mktemp -u /tmp/nbdkit-test-sock.XXXXXX)
+files="$sock cache-on-read.pid"
 rm -f $files
 cleanup_fn rm -f $files
 
-# Create an empty base image.
-truncate -s 128K cache-on-read.img
-
 # Run nbdkit with the caching filter and cache-on-read set.
 start_nbdkit -P cache-on-read.pid -U $sock \
              --filter=cache \
-             file cache-on-read.img \
-             cache-on-read=true
+             memory 128K cache-on-read=true
 
 nbdsh --connect "nbd+unix://?socket=$sock" \
       -c '
@@ -60,9 +56,4 @@ zero = h.pread(32768, 0)
 assert zero == bytearray(32768)
 buf2 = h.pread(65536, 32768)
 assert buf == buf2
-
-# XXX Suggestion to improve this test: Use the delay filter below the
-# cache filter, and time reads to prove that the second read is faster
-# because it is not going through the delay filter and plugin.
-# XXX second h.pread here ...
 '
