@@ -1,5 +1,5 @@
 /* nbdkit
- * Copyright (C) 2018-2021 Red Hat Inc.
+ * Copyright Red Hat
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are
@@ -60,6 +60,8 @@
 #include "byte-swapping.h"
 #include "cleanup.h"
 
+#include "requires.h"
+
 /* Declare program_name. */
 #if HAVE_DECL_PROGRAM_INVOCATION_SHORT_NAME == 1
 #include <errno.h>
@@ -73,7 +75,7 @@
 static void *start_log_capture (void *);
 static void log_verify_seen (const char *msg);
 static void log_verify_seen_in_order (const char *msg, ...)
-  __attribute__((sentinel));
+  __attribute__ ((sentinel));
 static void log_free (void);
 static void short_sleep (void);
 
@@ -101,11 +103,7 @@ main (int argc, char *argv[])
   int orig_stderr;
   char data[512];
 
-  if (system ("nbdkit --exit-with-parent --version") != 0) {
-    printf ("%s: this test requires --exit-with-parent functionality\n",
-            program_name);
-    exit (77);
-  }
+  requires ("nbdkit --exit-with-parent --version");
 
   /* Prepare libnbd. */
   fprintf (stderr, "%s: beginning test\n", program_name);
@@ -697,7 +695,7 @@ static void short_sleep (void)
  * NB: The log buffer is NOT \0-terminated.
  */
 
-static void no_message_error (const char *msg) __attribute__((noreturn));
+static void no_message_error (const char *msg) __attribute__ ((noreturn));
 
 static void
 no_message_error (const char *msg)
@@ -716,7 +714,7 @@ log_verify_seen (const char *msg)
 }
 
 static void messages_out_of_order (const char *msg1, const char *msg2)
-  __attribute__((noreturn));
+  __attribute__ ((noreturn));
 
 static void
 messages_out_of_order (const char *msg1, const char *msg2)
@@ -765,9 +763,7 @@ log_free (void)
 int
 main (int argc, char *argv[])
 {
-  fprintf (stderr, "%s: test skipped because not ported to Windows.\n",
-           argv[0]);
-  exit (77);
+  skip_because ("not ported to Windows");
 }
 
 #endif /* WIN32 */
