@@ -1,6 +1,6 @@
 #!/usr/bin/env bash
 # nbdkit
-# Copyright (C) 2017 Red Hat Inc.
+# Copyright Red Hat
 #
 # Redistribution and use in source and binary forms, with or without
 # modification, are permitted provided that the following conditions are
@@ -34,9 +34,9 @@ source ./functions.sh
 
 pidfile=shebang-python.pid
 sock=$(mktemp -u /tmp/nbdkit-test-sock.XXXXXX)
-script=$SRCDIR/shebang.py
+script=$abs_top_srcdir/tests/shebang.py
 
-if test ! -d "$SRCDIR"; then
+if test ! -f "$script"; then
     echo "$0: could not locate shebang.py"
     exit 1
 fi
